@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 if RUBY_PLATFORM == 'java'
   require 'java'
   require 'jdbc/mysql'
@@ -15,6 +17,8 @@ require 'active_support/core_ext/module/delegation'
 require 'active_support/core_ext/module/attribute_accessors'
 
 module ThinkingSphinx
+  MAXIMUM_STATEMENT_LENGTH = (2 ** 23) - 5
+
   def self.count(query = '', options = {})
     search_for_ids(query, options).total_entries
   end
@@ -38,17 +42,35 @@ module ThinkingSphinx
 
   @before_index_hooks = []
 
-  module Subscribers; end
+  def self.output
+    @output
+  end
+
+  @output = STDOUT
+
+  def self.rake_interface
+    @rake_interface ||= ThinkingSphinx::RakeInterface
+  end
+
+  def self.rake_interface=(interface)
+    @rake_interface = interface
+  end
+
+  module Hooks; end
   module IndexingStrategies; end
+  module Subscribers; end
 end
 
 # Core
+require 'thinking_sphinx/attribute_types'
 require 'thinking_sphinx/batched_search'
 require 'thinking_sphinx/callbacks'
 require 'thinking_sphinx/core'
+require 'thinking_sphinx/with_output'
+require 'thinking_sphinx/commander'
+require 'thinking_sphinx/commands'
 require 'thinking_sphinx/configuration'
 require 'thinking_sphinx/connection'
-require 'thinking_sphinx/controller'
 require 'thinking_sphinx/deletion'
 require 'thinking_sphinx/errors'
 require 'thinking_sphinx/excerpter'
@@ -57,10 +79,12 @@ require 'thinking_sphinx/facet_search'
 require 'thinking_sphinx/float_formatter'
 require 'thinking_sphinx/frameworks'
 require 'thinking_sphinx/guard'
+require 'thinking_sphinx/hooks/guard_presence'
 require 'thinking_sphinx/index'
 require 'thinking_sphinx/indexing_strategies/all_at_once'
 require 'thinking_sphinx/indexing_strategies/one_at_a_time'
 require 'thinking_sphinx/index_set'
+require 'thinking_sphinx/interfaces'
 require 'thinking_sphinx/masks'
 require 'thinking_sphinx/middlewares'
 require 'thinking_sphinx/panes'
@@ -68,7 +92,7 @@ require 'thinking_sphinx/query'
 require 'thinking_sphinx/rake_interface'
 require 'thinking_sphinx/scopes'
 require 'thinking_sphinx/search'
-require 'thinking_sphinx/sphinxql'
+require 'thinking_sphinx/settings'
 require 'thinking_sphinx/subscribers/populator_subscriber'
 require 'thinking_sphinx/test'
 require 'thinking_sphinx/utf8'
@@ -81,3 +105,5 @@ require 'thinking_sphinx/logger'
 require 'thinking_sphinx/real_time'
 
 require 'thinking_sphinx/railtie' if defined?(Rails::Railtie)
+
+ThinkingSphinx.before_index_hooks << ThinkingSphinx::Hooks::GuardPresence
