@@ -1,8 +1,11 @@
+# frozen_string_literal: true
+
 require 'active_record'
 require 'joiner'
 
 module ThinkingSphinx::ActiveRecord
   module Callbacks; end
+  module Depolymorph; end
 end
 
 require 'thinking_sphinx/active_record/property'
@@ -14,7 +17,6 @@ require 'thinking_sphinx/active_record/column'
 require 'thinking_sphinx/active_record/column_sql_presenter'
 require 'thinking_sphinx/active_record/database_adapters'
 require 'thinking_sphinx/active_record/field'
-require 'thinking_sphinx/active_record/filter_reflection'
 require 'thinking_sphinx/active_record/index'
 require 'thinking_sphinx/active_record/interpreter'
 require 'thinking_sphinx/active_record/join_association'
@@ -30,3 +32,10 @@ require 'thinking_sphinx/active_record/sql_source'
 require 'thinking_sphinx/active_record/callbacks/delete_callbacks'
 require 'thinking_sphinx/active_record/callbacks/delta_callbacks'
 require 'thinking_sphinx/active_record/callbacks/update_callbacks'
+
+require 'thinking_sphinx/active_record/depolymorph/base_reflection'
+require 'thinking_sphinx/active_record/depolymorph/association_reflection'
+require 'thinking_sphinx/active_record/depolymorph/conditions_reflection'
+require 'thinking_sphinx/active_record/depolymorph/overridden_reflection'
+require 'thinking_sphinx/active_record/depolymorph/scoped_reflection'
+require 'thinking_sphinx/active_record/filter_reflection'
