@@ -1,12 +1,12 @@
+# frozen_string_literal: true
+
 class ThinkingSphinx::ActiveRecord::Callbacks::DeltaCallbacks <
   ThinkingSphinx::Callbacks
 
   callbacks :after_commit, :before_save
 
   def after_commit
-    return unless !suspended? && delta_indices? && processors.any? { |processor|
-      processor.toggled?(instance)
-    }
+    return unless !suspended? && delta_indices? && toggled?
 
     delta_indices.each do |index|
       index.delta_processor.index index
@@ -18,7 +18,8 @@ class ThinkingSphinx::ActiveRecord::Callbacks::DeltaCallbacks <
   end
 
   def before_save
-    return unless !ThinkingSphinx::Callbacks.suspended? && delta_indices?
+    return unless !ThinkingSphinx::Callbacks.suspended? && delta_indices? &&
+      new_or_changed?
 
     processors.each { |processor| processor.toggle instance }
   end
@@ -42,7 +43,12 @@ class ThinkingSphinx::ActiveRecord::Callbacks::DeltaCallbacks <
   end
 
   def indices
-    @indices ||= config.index_set_class.new :classes => [instance.class]
+    @indices ||= config.index_set_class.new(:classes => [instance.class]).
+      select { |index| index.type == "plain" }
+  end
+
+  def new_or_changed?
+    instance.new_record? || instance.changed?
   end
 
   def processors
@@ -52,4 +58,8 @@ class ThinkingSphinx::ActiveRecord::Callbacks::DeltaCallbacks <
   def suspended?
     ThinkingSphinx::Callbacks.suspended? || ThinkingSphinx::Deltas.suspended?
   end
+
+  def toggled?
+    processors.any? { |processor| processor.toggled?(instance) }
+  end
 end
