@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module ThinkingSphinx
   module ActiveRecord
     class SQLBuilder::Query
@@ -45,6 +47,10 @@ module ThinkingSphinx
         self.scope += utf8_query_pre if source.options[:utf8?]
       end
 
+      def source
+        report.source
+      end
+      
       def method_missing(*args, &block)
         report.send *args, &block
       end
