@@ -1,8 +1,11 @@
+# frozen_string_literal: true
+
 module ThinkingSphinx
   module ActiveRecord
     class SQLSource < Riddle::Configuration::SQLSource
       include ThinkingSphinx::Core::Settings
-      attr_reader :model, :database_settings, :options
+
+      attr_reader :model, :options
       attr_accessor :fields, :attributes, :associations, :conditions,
         :groupings, :polymorphs
 
@@ -12,9 +15,8 @@ module ThinkingSphinx
 
       def initialize(model, options = {})
         @model             = model
-        @database_settings = model.connection.instance_variable_get(:@config).clone
         @options           = {
-          :utf8? => (@database_settings[:encoding] == 'utf8')
+          :utf8? => (database_settings[:encoding].to_s[/^utf8/])
         }.merge options
 
         @fields            = []
@@ -90,7 +92,7 @@ module ThinkingSphinx
         when DatabaseAdapters::PostgreSQLAdapter
           'pgsql'
         else
-          raise "Unknown Adapter Type: #{adapter.class.name}"
+          raise UnknownDatabaseAdapter, "Provided type: #{adapter.class.name}"
         end
       end
 
@@ -132,6 +134,16 @@ module ThinkingSphinx
         ThinkingSphinx::Configuration.instance
       end
 
+      def database_settings
+        @database_settings ||= begin
+          if model.connection.respond_to?(:config)
+            model.connection.config.clone
+          else
+            model.connection.instance_variable_get(:@config).clone
+          end
+        end
+      end
+
       def prepare_for_render
         polymorphs.each &:morph!
         append_presenter_to_attribute_array
