@@ -1,9 +1,12 @@
+# frozen_string_literal: true
+
 require 'pathname'
 
 class ThinkingSphinx::Configuration < Riddle::Configuration
-  attr_accessor :configuration_file, :indices_location, :version
+  attr_accessor :configuration_file, :indices_location, :version, :batch_size
   attr_reader :index_paths
-  attr_writer :controller, :index_set_class, :indexing_strategy
+  attr_writer :controller, :index_set_class, :indexing_strategy,
+    :guarding_strategy
 
   delegate :environment, :to => :framework
 
@@ -29,7 +32,7 @@ class ThinkingSphinx::Configuration < Riddle::Configuration
 
   def controller
     @controller ||= begin
-      rc = ThinkingSphinx::Controller.new self, configuration_file
+      rc = Riddle::Controller.new self, configuration_file
       rc.bin_path = bin_path.gsub(/([^\/])$/, '\1/') if bin_path.present?
       rc
     end
@@ -48,7 +51,7 @@ class ThinkingSphinx::Configuration < Riddle::Configuration
   def engine_index_paths
     return [] unless defined?(Rails)
 
-    engine_indice_paths.flatten.compact
+    engine_indice_paths.flatten.compact.sort
   end
 
   def engine_indice_paths
@@ -58,6 +61,10 @@ class ThinkingSphinx::Configuration < Riddle::Configuration
     end
   end
 
+  def guarding_strategy
+    @guarding_strategy ||= ThinkingSphinx::Guard::Files
+  end
+
   def index_set_class
     @index_set_class ||= ThinkingSphinx::IndexSet
   end
@@ -84,9 +91,8 @@ class ThinkingSphinx::Configuration < Riddle::Configuration
         end
       end
 
-      if settings['distributed_indices'].nil? || settings['distributed_indices']
-        ThinkingSphinx::Configuration::DistributedIndices.new(indices).reconcile
-      end
+      normalise
+      verify
 
       @preloaded_indices = true
     end
@@ -95,10 +101,6 @@ class ThinkingSphinx::Configuration < Riddle::Configuration
   def render
     preload_indices
 
-    ThinkingSphinx::Configuration::ConsistentIds.new(indices).reconcile
-    ThinkingSphinx::Configuration::MinimumFields.new(indices).reconcile
-    ThinkingSphinx::Configuration::DuplicateNames.new(indices).reconcile
-
     super
   end
 
@@ -109,18 +111,16 @@ class ThinkingSphinx::Configuration < Riddle::Configuration
   end
 
   def settings
-    @settings ||= File.exists?(settings_file) ? settings_to_hash : {}
+    @settings ||= ThinkingSphinx::Settings.call self
   end
 
   def setup
-    @configuration_file = settings['configuration_file'] || framework_root.join(
-      'config', "#{environment}.sphinx.conf"
-    ).to_s
-    @index_paths = engine_index_paths + [framework_root.join('app', 'indices').to_s]
-    @indices_location = settings['indices_location'] || framework_root.join(
-      'db', 'sphinx', environment
-    ).to_s
-    @version = settings['version'] || '2.1.4'
+    @configuration_file = settings['configuration_file']
+    @index_paths = engine_index_paths +
+      [Pathname.new(framework.root).join('app', 'indices').to_s]
+    @indices_location = settings['indices_location']
+    @version = settings['version'] || '2.2.11'
+    @batch_size = settings['batch_size'] || 1000
 
     if settings['common_sphinx_configuration']
       common.common_sphinx_configuration  = true
@@ -136,62 +136,6 @@ class ThinkingSphinx::Configuration < Riddle::Configuration
 
   private
 
-  def configure_searchd
-    configure_searchd_log_files
-
-    searchd.binlog_path = tmp_path.join('binlog', environment).to_s
-    searchd.address = settings['address'].presence || Defaults::ADDRESS
-    searchd.mysql41 = settings['mysql41'] || settings['port'] || Defaults::PORT
-    searchd.workers = 'threads'
-    searchd.mysql_version_string = '5.5.21' if RUBY_PLATFORM == 'java'
-  end
-
-  def configure_searchd_log_files
-    searchd.pid_file = log_root.join("#{environment}.sphinx.pid").to_s
-    searchd.log = log_root.join("#{environment}.searchd.log").to_s
-    searchd.query_log = log_root.join("#{environment}.searchd.query.log").to_s
-  end
-
-  def log_root
-    real_path 'log'
-  end
-
-  def framework_root
-    Pathname.new(framework.root)
-  end
-
-  def real_path(*arguments)
-    path = framework_root.join(*arguments)
-    path.exist? ? path.realpath : path
-  end
-
-  def settings_to_hash
-    input    = File.read settings_file
-    input    = ERB.new(input).result if defined?(ERB)
-
-    contents = YAML.load input
-    contents && contents[environment] || {}
-  end
-
-  def settings_file
-    framework_root.join 'config', 'thinking_sphinx.yml'
-  end
-
-  def reset
-    @settings = nil
-    setup
-  end
-
-  def tmp_path
-    real_path 'tmp'
-  end
-
-  def sphinx_sections
-    sections = [indexer, searchd]
-    sections.unshift common if settings['common_sphinx_configuration']
-    sections
-  end
-
   def apply_sphinx_settings!
     sphinx_sections.each do |object|
       settings.each do |key, value|
@@ -201,6 +145,52 @@ class ThinkingSphinx::Configuration < Riddle::Configuration
       end
     end
   end
+
+  def configure_searchd
+    searchd.socket = "#{settings["socket"]}:mysql41" if socket?
+
+    if tcp?
+      searchd.address = settings['address'].presence || Defaults::ADDRESS
+      searchd.mysql41 = settings['mysql41'] || settings['port'] || Defaults::PORT
+    end
+
+    searchd.mysql_version_string = '5.5.21' if RUBY_PLATFORM == 'java'
+  end
+
+  def normalise
+    if settings['distributed_indices'].nil? || settings['distributed_indices']
+      ThinkingSphinx::Configuration::DistributedIndices.new(indices).reconcile
+    end
+
+    ThinkingSphinx::Configuration::ConsistentIds.new(indices).reconcile
+    ThinkingSphinx::Configuration::MinimumFields.new(indices).reconcile
+  end
+
+  def reset
+    @settings = nil
+    setup
+  end
+
+  def socket?
+    settings["socket"].present?
+  end
+
+  def sphinx_sections
+    sections = [indexer, searchd]
+    sections.unshift common if settings['common_sphinx_configuration']
+    sections
+  end
+
+  def tcp?
+    settings["socket"].nil?      ||
+    settings["address"].present? ||
+    settings["mysql41"].present? ||
+    settings["port"].present?
+  end
+
+  def verify
+    ThinkingSphinx::Configuration::DuplicateNames.new(indices).reconcile
+  end
 end
 
 require 'thinking_sphinx/configuration/consistent_ids'
