@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class ThinkingSphinx::Deletion
   delegate :name, :to => :index
 
@@ -25,8 +27,12 @@ class ThinkingSphinx::Deletion
   end
 
   def execute(statement)
-    ThinkingSphinx::Connection.take do |connection|
-      connection.execute statement
+    statement = statement.gsub(/\s*\n\s*/, ' ').strip
+
+    ThinkingSphinx::Logger.log :query, statement do
+      ThinkingSphinx::Connection.take do |connection|
+        connection.execute statement
+      end
     end
   end
 
