@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class ThinkingSphinx::Deltas::DefaultDelta
   attr_reader :adapter, :options
 
@@ -13,7 +15,7 @@ class ThinkingSphinx::Deltas::DefaultDelta
 
   def delete(index, instance)
     ThinkingSphinx::Deltas::DeleteJob.new(
-      index.name, index.document_id_for_key(instance.id)
+      index.name, index.document_id_for_instance(instance)
     ).perform
   end
 
