@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class ThinkingSphinx::Distributed::Index <
   Riddle::Configuration::DistributedIndex
 
@@ -21,4 +23,14 @@ class ThinkingSphinx::Distributed::Index <
   def model
     @model ||= reference.to_s.camelize.constantize
   end
+
+  def primary_key
+    @primary_key ||= configuration.settings['primary_key'] || :id
+  end
+
+  private
+
+  def configuration
+    ThinkingSphinx::Configuration.instance
+  end
 end
