@@ -1,6 +1,9 @@
+# frozen_string_literal: true
+
 module ThinkingSphinx::Guard
   #
 end
 
 require 'thinking_sphinx/guard/file'
 require 'thinking_sphinx/guard/files'
+require 'thinking_sphinx/guard/none'
