@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class ThinkingSphinx::Masks::WeightEnumeratorMask
   def initialize(search)
     @search = search
@@ -9,7 +11,7 @@ class ThinkingSphinx::Masks::WeightEnumeratorMask
 
   def each_with_weight(&block)
     @search.raw.each_with_index do |row, index|
-      yield @search[index], row[ThinkingSphinx::SphinxQL.weight[:column]]
+      yield @search[index], row["weight()"]
     end
   end
 end
