@@ -1,7 +1,11 @@
+# frozen_string_literal: true
+
 module ThinkingSphinx::Middlewares; end
 
-%w[middleware active_record_translator geographer glazier ids_only inquirer
-   sphinxql stale_id_checker stale_id_filter utf8].each do |middleware|
+%w[
+  middleware active_record_translator geographer glazier ids_only inquirer
+  sphinxql stale_id_checker stale_id_filter valid_options
+].each do |middleware|
   require "thinking_sphinx/middlewares/#{middleware}"
 end
 
@@ -10,7 +14,7 @@ module ThinkingSphinx::Middlewares
     middlewares.each { |m| builder.use m }
   end
 
-  BASE_MIDDLEWARES = [SphinxQL, Geographer, Inquirer]
+  BASE_MIDDLEWARES = [ValidOptions, SphinxQL, Geographer, Inquirer]
 
   DEFAULT = ::Middleware::Builder.new do
     use StaleIdFilter
