@@ -1,10 +1,12 @@
+# frozen_string_literal: true
+
 module ThinkingSphinx::RealTime
   module Callbacks
     #
   end
 
   def self.callback_for(reference, path = [], &block)
-    Callbacks::RealTimeCallbacks.new reference, path, &block
+    Callbacks::RealTimeCallbacks.new reference.to_sym, path, &block
   end
 end
 
@@ -14,6 +16,7 @@ require 'thinking_sphinx/real_time/field'
 require 'thinking_sphinx/real_time/index'
 require 'thinking_sphinx/real_time/interpreter'
 require 'thinking_sphinx/real_time/populator'
+require 'thinking_sphinx/real_time/transcribe_instance'
 require 'thinking_sphinx/real_time/transcriber'
 require 'thinking_sphinx/real_time/translator'
 
