@@ -1,16 +1,16 @@
+# frozen_string_literal: true
+
 class ThinkingSphinx::RealTime::Callbacks::RealTimeCallbacks
   def initialize(reference, path = [], &block)
     @reference, @path, @block = reference, path, block
   end
 
-  def after_save(instance)
-    return unless real_time_indices? && callbacks_enabled?
+  def after_commit(instance)
+    persist_changes instance
+  end
 
-    real_time_indices.each do |index|
-      objects_for(instance).each do |object|
-        ThinkingSphinx::RealTime::Transcriber.new(index).copy object
-      end
-    end
+  def after_save(instance)
+    persist_changes instance
   end
 
   private
@@ -40,6 +40,16 @@ class ThinkingSphinx::RealTime::Callbacks::RealTimeCallbacks
     Array results
   end
 
+  def persist_changes(instance)
+    return unless real_time_indices? && callbacks_enabled?
+
+    real_time_indices.each do |index|
+      objects_for(instance).each do |object|
+        ThinkingSphinx::RealTime::Transcriber.new(index).copy object
+      end
+    end
+  end
+
   def real_time_indices?
     real_time_indices.any?
   end
