@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class ThinkingSphinx::RealTime::Populator
   def self.populate(index)
     new(index).populate
@@ -10,14 +12,11 @@ class ThinkingSphinx::RealTime::Populator
   def populate(&block)
     instrument 'start_populating'
 
-    remove_files
-
-    scope.find_in_batches do |instances|
+    scope.find_in_batches(:batch_size => batch_size) do |instances|
       transcriber.copy *instances
       instrument 'populated', :instances => instances
     end
 
-    controller.rotate
     instrument 'finish_populating'
   end
 
@@ -25,8 +24,8 @@ class ThinkingSphinx::RealTime::Populator
 
   attr_reader :index
 
-  delegate :controller, :to => :configuration
-  delegate :scope,      :to => :index
+  delegate :controller, :batch_size, :to => :configuration
+  delegate :scope,                   :to => :index
 
   def configuration
     ThinkingSphinx::Configuration.instance
@@ -38,10 +37,6 @@ class ThinkingSphinx::RealTime::Populator
     )
   end
 
-  def remove_files
-    Dir["#{index.path}*"].each { |file| FileUtils.rm file }
-  end
-
   def transcriber
     @transcriber ||= ThinkingSphinx::RealTime::Transcriber.new index
   end
