@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class ThinkingSphinx::RealTime::Translator
   def self.call(object, column)
     new(object, column).call
@@ -11,7 +13,7 @@ class ThinkingSphinx::RealTime::Translator
     return name   unless name.is_a?(Symbol)
     return result unless result.is_a?(String)
 
-    result.gsub "\u0000", ''
+    result.gsub("\u0000", '').force_encoding "UTF-8"
   end
 
   private
