@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class ThinkingSphinx::Search < Array
   CORE_METHODS = %w( == class class_eval extend frozen? id instance_eval
     instance_of? instance_values instance_variable_defined?
@@ -6,6 +8,15 @@ class ThinkingSphinx::Search < Array
     respond_to_missing? send should should_not type )
   SAFE_METHODS = %w( partition private_methods protected_methods public_methods
     send class )
+  KNOWN_OPTIONS = (
+    [
+      :classes, :conditions, :geo, :group_by, :ids_only, :ignore_scopes,
+      :indices, :limit, :masks, :max_matches, :middleware, :offset, :order,
+      :order_group_by, :page, :per_page, :populate, :retry_stale, :select,
+      :skip_sti, :sql, :star, :with, :with_all, :without, :without_ids
+    ] +
+    ThinkingSphinx::Middlewares::SphinxQL::SELECT_OPTIONS
+  ).uniq
   DEFAULT_MASKS = [
     ThinkingSphinx::Masks::PaginationMask,
     ThinkingSphinx::Masks::ScopesMask,
@@ -21,6 +32,12 @@ class ThinkingSphinx::Search < Array
   attr_reader   :options
   attr_accessor :query
 
+  def self.valid_options
+    @valid_options
+  end
+
+  @valid_options = KNOWN_OPTIONS.dup
+
   def initialize(query = nil, options = {})
     query, options   = nil, query if query.is_a?(Hash)
     @query, @options = query, options
