@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class ThinkingSphinx::Wildcard
   DEFAULT_TOKEN = /\p{Word}+/
 
@@ -14,7 +16,7 @@ class ThinkingSphinx::Wildcard
     query.gsub(extended_pattern) do
       pre, proper, post = $`, $&, $'
       # E.g. "@foo", "/2", "~3", but not as part of a token pattern
-      is_operator = pre == '@' ||
+      is_operator = pre.match(%r{@$}) ||
                     pre.match(%r{([^\\]+|\A)[~/]\Z}) ||
                     pre.match(%r{(\W|^)@\([^\)]*$})
       # E.g. "foo bar", with quotes
