@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class SphinxController
   def initialize
     config.searchd.mysql41 = 9307
@@ -16,10 +18,6 @@ class SphinxController
 
     ActiveSupport::Dependencies.clear
 
-    if ENV['SPHINX_VERSION'].try :[], /2.0.\d/
-      ThinkingSphinx::Configuration.instance.settings['utf8'] = false
-    end
-
     config.searchd.mysql41 = 9307
     config.settings['quiet_deltas']      = true
     config.settings['attribute_updates'] = true
@@ -28,14 +26,30 @@ class SphinxController
 
   def start
     config.controller.start
+  rescue Riddle::CommandFailedError => error
+    puts <<-TXT
+
+The Sphinx start command failed:
+  Command: #{error.command_result.command}
+  Status:  #{error.command_result.status}
+  Output:  #{error.command_result.output}
+    TXT
+    raise error
   end
 
   def stop
-    config.controller.stop
+    while config.controller.running? do
+      config.controller.stop
+      sleep(0.1)
+    end
   end
 
   def index(*indices)
-    config.controller.index *indices
+    ThinkingSphinx::Commander.call :index_sql, config, :indices => indices
+  end
+
+  def merge
+    ThinkingSphinx::Commander.call(:merge_and_update, config, {})
   end
 
   private
