@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module SphinxHelpers
   def sphinx
     @sphinx ||= SphinxController.new
@@ -12,6 +14,15 @@ module SphinxHelpers
     sleep 0.25
     sleep 0.5 if ENV['TRAVIS']
   end
+
+  def merge
+    sleep 0.5 if ENV['TRAVIS']
+    sleep 0.5
+
+    sphinx.merge
+    sleep 1.5
+    sleep 0.5 if ENV['TRAVIS']
+  end
 end
 
 RSpec.configure do |config|
@@ -27,4 +38,8 @@ RSpec.configure do |config|
   config.after :all do |group|
     sphinx.stop if group.class.metadata[:live]
   end
+
+  config.after :suite do
+    SphinxController.new.stop
+  end
 end
