@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 multi_schema = MultiSchema.new
 
 ThinkingSphinx::Index.define :product, :with => :real_time do
@@ -8,8 +10,6 @@ ThinkingSphinx::Index.define :product, :with => :real_time do
 end
 
 if multi_schema.active?
-  multi_schema.create 'thinking_sphinx'
-
   ThinkingSphinx::Index.define(:product,
     :name => :product_two, :offset_as => :product_two, :with => :real_time
   ) do
