@@ -1,9 +1,19 @@
+# frozen_string_literal: true
+
 ActiveRecord::Schema.define do
   create_table(:admin_people, :force => true) do |t|
     t.string :name
     t.timestamps null: false
   end
 
+  create_table(:albums, :force => true, :id => false) do |t|
+    t.string :id
+    t.integer :integer_id
+    t.string :name
+    t.string :artist
+    t.boolean :delta, :default => true, :null => false
+  end
+
   create_table(:animals, :force => true) do |t|
     t.string :name
     t.string :type
