@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class JSONColumn
   include ActiveRecord::ConnectionAdapters
 
@@ -6,7 +8,7 @@ class JSONColumn
   end
 
   def call
-    postgresql? && column?
+    ruby? && postgresql? && column?
   end
 
   private
@@ -26,4 +28,8 @@ class JSONColumn
   def postgresql?
     ENV['DATABASE'] == 'postgresql'
   end
+
+  def ruby?
+    RUBY_PLATFORM != 'java'
+  end
 end
