@@ -1,6 +1,8 @@
+# frozen_string_literal: true
+
 module SphinxYamlHelpers
   def write_configuration(hash)
-    File.stub :read => {'test' => hash}.to_yaml, :exists? => true
+    allow(File).to receive_messages :read => {'test' => hash}.to_yaml, :exists? => true
   end
 end
 
