@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'spec_helper'
 
 describe ThinkingSphinx::ActiveRecord::Association do
@@ -6,7 +8,7 @@ describe ThinkingSphinx::ActiveRecord::Association do
 
   describe '#stack' do
     it "returns the column's stack and name" do
-      association.stack.should == [:users, :post]
+      expect(association.stack).to eq([:users, :post])
     end
   end
 end
