@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'spec_helper'
 
 describe ThinkingSphinx::ActiveRecord::SQLBuilder do
@@ -22,24 +24,24 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
   let(:builder)      { ThinkingSphinx::ActiveRecord::SQLBuilder.new source }
 
   before :each do
-    ThinkingSphinx::Configuration.stub! :instance => config
-    ThinkingSphinx::ActiveRecord::PropertySQLPresenter.stub! :new => presenter
-    Joiner::Joins.stub! :new => associations
-    relation.stub! :select => relation, :where => relation, :group => relation,
+    allow(ThinkingSphinx::Configuration).to receive_messages :instance => config
+    allow(ThinkingSphinx::ActiveRecord::PropertySQLPresenter).to receive_messages :new => presenter
+    allow(Joiner::Joins).to receive_messages :new => associations
+    allow(relation).to receive_messages :select => relation, :where => relation, :group => relation,
       :order => relation, :joins => relation, :to_sql => ''
-    connection.stub!(:quote_column_name) { |column| "`#{column}`"}
+    allow(connection).to receive(:quote_column_name) { |column| "`#{column}`"}
   end
 
   describe 'sql_query' do
     before :each do
-      source.stub! :type => 'mysql'
+      allow(source).to receive_messages :type => 'mysql'
     end
 
     it "adds source associations to the joins of the query" do
       source.associations << double('association',
         :stack => [:user, :posts], :string? => false)
 
-      associations.should_receive(:add_join_to).with([:user, :posts])
+      expect(associations).to receive(:add_join_to).with([:user, :posts])
 
       builder.sql_query
     end
@@ -48,25 +50,25 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       source.associations << double('association',
         :to_s => 'my string', :string? => true)
 
-      relation.should_receive(:joins).with(['my string']).and_return(relation)
+      expect(relation).to receive(:joins).with(['my string']).and_return(relation)
 
       builder.sql_query
     end
 
     context 'MySQL adapter' do
       before :each do
-        source.stub! :type => 'mysql'
+        allow(source).to receive_messages :type => 'mysql'
       end
 
       it "returns the relation's query" do
-        relation.stub! :to_sql => 'SELECT * FROM people'
+        allow(relation).to receive_messages :to_sql => 'SELECT * FROM people'
 
-        builder.sql_query.should == 'SELECT * FROM people'
+        expect(builder.sql_query).to eq('SELECT * FROM people')
       end
 
       it "ensures results aren't from cache" do
-        relation.should_receive(:select) do |string|
-          string.should match(/^SQL_NO_CACHE /)
+        expect(relation).to receive(:select) do |string|
+          expect(string).to match(/^SQL_NO_CACHE /)
           relation
         end
 
@@ -74,8 +76,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       end
 
       it "adds the document id using the offset and index count" do
-        relation.should_receive(:select) do |string|
-          string.should match(/`users`.`id` \* 5 \+ 3 AS `id`/)
+        expect(relation).to receive(:select) do |string|
+          expect(string).to match(/`users`.`id` \* 5 \+ 3 AS `id`/)
           relation
         end
 
@@ -85,8 +87,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       it "adds each field to the SELECT clause" do
         source.fields << double('field')
 
-        relation.should_receive(:select) do |string|
-          string.should match(/`name` AS `name`/)
+        expect(relation).to receive(:select) do |string|
+          expect(string).to match(/`name` AS `name`/)
           relation
         end
 
@@ -95,10 +97,10 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
 
       it "adds each attribute to the SELECT clause" do
         source.attributes << double('attribute')
-        presenter.stub!(:to_select => '`created_at` AS `created_at`')
+        allow(presenter).to receive_messages(:to_select => '`created_at` AS `created_at`')
 
-        relation.should_receive(:select) do |string|
-          string.should match(/`created_at` AS `created_at`/)
+        expect(relation).to receive(:select) do |string|
+          expect(string).to match(/`created_at` AS `created_at`/)
           relation
         end
 
@@ -106,8 +108,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       end
 
       it "limits results to a set range" do
-        relation.should_receive(:where) do |string|
-          string.should match(/`users`.`id` BETWEEN \$start AND \$end/)
+        expect(relation).to receive(:where) do |string|
+          expect(string).to match(/`users`.`id` BETWEEN \$start AND \$end/)
           relation
         end
 
@@ -115,10 +117,10 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       end
 
       it "shouldn't limit results to a range if ranges are disabled" do
-        source.stub! :disable_range? => true
+        allow(source).to receive_messages :disable_range? => true
 
-        relation.should_receive(:where) do |string|
-          string.should_not match(/`users`.`id` BETWEEN \$start AND \$end/)
+        expect(relation).to receive(:where) do |string|
+          expect(string).not_to match(/`users`.`id` BETWEEN \$start AND \$end/)
           relation
         end
 
@@ -128,8 +130,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       it "adds source conditions" do
         source.conditions << 'created_at > NOW()'
 
-        relation.should_receive(:where) do |string|
-          string.should match(/created_at > NOW()/)
+        expect(relation).to receive(:where) do |string|
+          expect(string).to match(/created_at > NOW()/)
           relation
         end
 
@@ -137,8 +139,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       end
 
       it "groups by the primary key" do
-        relation.should_receive(:group) do |string|
-          string.should match(/`users`.`id`/)
+        expect(relation).to receive(:group) do |string|
+          expect(string).to match(/`users`.`id`/)
           relation
         end
 
@@ -148,8 +150,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       it "groups each field" do
         source.fields << double('field')
 
-        relation.should_receive(:group) do |string|
-          string.should match(/`name`/)
+        expect(relation).to receive(:group) do |string|
+          expect(string).to match(/`name`/)
           relation
         end
 
@@ -158,10 +160,10 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
 
       it "groups each attribute" do
         source.attributes << double('attribute')
-        presenter.stub!(:to_group => '`created_at`')
+        allow(presenter).to receive_messages(:to_group => '`created_at`')
 
-        relation.should_receive(:group) do |string|
-          string.should match(/`created_at`/)
+        expect(relation).to receive(:group) do |string|
+          expect(string).to match(/`created_at`/)
           relation
         end
 
@@ -171,8 +173,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       it "groups by source groupings" do
         source.groupings << '`latitude`'
 
-        relation.should_receive(:group) do |string|
-          string.should match(/`latitude`/)
+        expect(relation).to receive(:group) do |string|
+          expect(string).to match(/`latitude`/)
           relation
         end
 
@@ -180,7 +182,7 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       end
 
       it "orders by NULL" do
-        relation.should_receive(:order).with('NULL').and_return(relation)
+        expect(relation).to receive(:order).with('NULL').and_return(relation)
 
         builder.sql_query
       end
@@ -188,13 +190,13 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       context 'STI model' do
         before :each do
           model.column_names << 'type'
-          model.stub! :descends_from_active_record? => false
-          model.stub! :store_full_sti_class => true
+          allow(model).to receive_messages :descends_from_active_record? => false
+          allow(model).to receive_messages :store_full_sti_class => true
         end
 
         it "groups by the inheritance column" do
-          relation.should_receive(:group) do |string|
-            string.should match(/`users`.`type`/)
+          expect(relation).to receive(:group) do |string|
+            expect(string).to match(/`users`.`type`/)
             relation
           end
 
@@ -204,12 +206,12 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
         context 'with a custom inheritance column' do
           before :each do
             model.column_names << 'custom_type'
-            model.stub :inheritance_column => 'custom_type'
+            allow(model).to receive_messages :inheritance_column => 'custom_type'
           end
 
           it "groups by the right column" do
-            relation.should_receive(:group) do |string|
-              string.should match(/`users`.`custom_type`/)
+            expect(relation).to receive(:group) do |string|
+              expect(string).to match(/`users`.`custom_type`/)
               relation
             end
 
@@ -222,14 +224,14 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
         let(:processor) { double('processor') }
 
         before :each do
-          source.stub! :delta_processor => processor
-          source.stub! :delta? => true
+          allow(source).to receive_messages :delta_processor => processor
+          allow(source).to receive_messages :delta? => true
         end
 
         it "filters by the provided clause" do
-          processor.should_receive(:clause).with(true).and_return('`delta` = 1')
-          relation.should_receive(:where) do |string|
-            string.should match(/`delta` = 1/)
+          expect(processor).to receive(:clause).with(true).and_return('`delta` = 1')
+          expect(relation).to receive(:where) do |string|
+            expect(string).to match(/`delta` = 1/)
             relation
           end
 
@@ -243,20 +245,20 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
         :to_group => '"name"') }
 
       before :each do
-        source.stub! :type => 'pgsql'
-        model.stub! :quoted_table_name => '"users"'
-        connection.stub!(:quote_column_name) { |column| "\"#{column}\""}
+        allow(source).to receive_messages :type => 'pgsql'
+        allow(model).to receive_messages :quoted_table_name => '"users"'
+        allow(connection).to receive(:quote_column_name) { |column| "\"#{column}\""}
       end
 
       it "returns the relation's query" do
-        relation.stub! :to_sql => 'SELECT * FROM people'
+        allow(relation).to receive_messages :to_sql => 'SELECT * FROM people'
 
-        builder.sql_query.should == 'SELECT * FROM people'
+        expect(builder.sql_query).to eq('SELECT * FROM people')
       end
 
       it "adds the document id using the offset and index count" do
-        relation.should_receive(:select) do |string|
-          string.should match(/"users"."id" \* 5 \+ 3 AS "id"/)
+        expect(relation).to receive(:select) do |string|
+          expect(string).to match(/"users"."id" \* 5 \+ 3 AS "id"/)
           relation
         end
 
@@ -266,8 +268,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       it "adds each field to the SELECT clause" do
         source.fields << double('field')
 
-        relation.should_receive(:select) do |string|
-          string.should match(/"name" AS "name"/)
+        expect(relation).to receive(:select) do |string|
+          expect(string).to match(/"name" AS "name"/)
           relation
         end
 
@@ -276,10 +278,10 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
 
       it "adds each attribute to the SELECT clause" do
         source.attributes << double('attribute')
-        presenter.stub!(:to_select => '"created_at" AS "created_at"')
+        allow(presenter).to receive_messages(:to_select => '"created_at" AS "created_at"')
 
-        relation.should_receive(:select) do |string|
-          string.should match(/"created_at" AS "created_at"/)
+        expect(relation).to receive(:select) do |string|
+          expect(string).to match(/"created_at" AS "created_at"/)
           relation
         end
 
@@ -287,8 +289,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       end
 
       it "limits results to a set range" do
-        relation.should_receive(:where) do |string|
-          string.should match(/"users"."id" BETWEEN \$start AND \$end/)
+        expect(relation).to receive(:where) do |string|
+          expect(string).to match(/"users"."id" BETWEEN \$start AND \$end/)
           relation
         end
 
@@ -296,10 +298,10 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       end
 
       it "shouldn't limit results to a range if ranges are disabled" do
-        source.stub! :disable_range? => true
+        allow(source).to receive_messages :disable_range? => true
 
-        relation.should_receive(:where) do |string|
-          string.should_not match(/"users"."id" BETWEEN \$start AND \$end/)
+        expect(relation).to receive(:where) do |string|
+          expect(string).not_to match(/"users"."id" BETWEEN \$start AND \$end/)
           relation
         end
 
@@ -309,8 +311,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       it "adds source conditions" do
         source.conditions << 'created_at > NOW()'
 
-        relation.should_receive(:where) do |string|
-          string.should match(/created_at > NOW()/)
+        expect(relation).to receive(:where) do |string|
+          expect(string).to match(/created_at > NOW()/)
           relation
         end
 
@@ -318,8 +320,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       end
 
       it "groups by the primary key" do
-        relation.should_receive(:group) do |string|
-          string.should match(/"users"."id"/)
+        expect(relation).to receive(:group) do |string|
+          expect(string).to match(/"users"."id"/)
           relation
         end
 
@@ -329,8 +331,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       it "groups each field" do
         source.fields << double('field')
 
-        relation.should_receive(:group) do |string|
-          string.should match(/"name"/)
+        expect(relation).to receive(:group) do |string|
+          expect(string).to match(/"name"/)
           relation
         end
 
@@ -339,10 +341,10 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
 
       it "groups each attribute" do
         source.attributes << double('attribute')
-        presenter.stub!(:to_group => '"created_at"')
+        allow(presenter).to receive_messages(:to_group => '"created_at"')
 
-        relation.should_receive(:group) do |string|
-          string.should match(/"created_at"/)
+        expect(relation).to receive(:group) do |string|
+          expect(string).to match(/"created_at"/)
           relation
         end
 
@@ -352,8 +354,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       it "groups by source groupings" do
         source.groupings << '"latitude"'
 
-        relation.should_receive(:group) do |string|
-          string.should match(/"latitude"/)
+        expect(relation).to receive(:group) do |string|
+          expect(string).to match(/"latitude"/)
           relation
         end
 
@@ -361,7 +363,7 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       end
 
       it "has no ORDER clause" do
-        relation.should_not_receive(:order)
+        expect(relation).not_to receive(:order)
 
         builder.sql_query
       end
@@ -372,8 +374,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
         end
 
         it "groups by the primary key" do
-          relation.should_receive(:group) do |string|
-            string.should match(/"users"."id"/)
+          expect(relation).to receive(:group) do |string|
+            expect(string).to match(/"users"."id"/)
             relation
           end
 
@@ -383,8 +385,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
         it "does not group by fields" do
           source.fields << double('field')
 
-          relation.should_receive(:group) do |string|
-            string.should_not match(/"name"/)
+          expect(relation).to receive(:group) do |string|
+            expect(string).not_to match(/"name"/)
             relation
           end
 
@@ -393,10 +395,10 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
 
         it "does not group by attributes" do
           source.attributes << double('attribute')
-          presenter.stub!(:to_group => '"created_at"')
+          allow(presenter).to receive_messages(:to_group => '"created_at"')
 
-          relation.should_receive(:group) do |string|
-            string.should_not match(/"created_at"/)
+          expect(relation).to receive(:group) do |string|
+            expect(string).not_to match(/"created_at"/)
             relation
           end
 
@@ -406,8 +408,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
         it "groups by source groupings" do
           source.groupings << '"latitude"'
 
-          relation.should_receive(:group) do |string|
-            string.should match(/"latitude"/)
+          expect(relation).to receive(:group) do |string|
+            expect(string).to match(/"latitude"/)
             relation
           end
 
@@ -421,8 +423,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
         end
 
         it "groups by the primary key" do
-          relation.should_receive(:group) do |string|
-            string.should match(/"users"."id"/)
+          expect(relation).to receive(:group) do |string|
+            expect(string).to match(/"users"."id"/)
             relation
           end
 
@@ -432,8 +434,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
         it "does not group by fields" do
           source.fields << double('field')
 
-          relation.should_receive(:group) do |string|
-            string.should_not match(/"name"/)
+          expect(relation).to receive(:group) do |string|
+            expect(string).not_to match(/"name"/)
             relation
           end
 
@@ -442,10 +444,10 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
 
         it "does not group by attributes" do
           source.attributes << double('attribute')
-          presenter.stub!(:to_group => '"created_at"')
+          allow(presenter).to receive_messages(:to_group => '"created_at"')
 
-          relation.should_receive(:group) do |string|
-            string.should_not match(/"created_at"/)
+          expect(relation).to receive(:group) do |string|
+            expect(string).not_to match(/"created_at"/)
             relation
           end
 
@@ -455,8 +457,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
         it "groups by source groupings" do
           source.groupings << '"latitude"'
 
-          relation.should_receive(:group) do |string|
-            string.should match(/"latitude"/)
+          expect(relation).to receive(:group) do |string|
+            expect(string).to match(/"latitude"/)
             relation
           end
 
@@ -467,13 +469,13 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       context 'STI model' do
         before :each do
           model.column_names << 'type'
-          model.stub! :descends_from_active_record? => false
-          model.stub! :store_full_sti_class => true
+          allow(model).to receive_messages :descends_from_active_record? => false
+          allow(model).to receive_messages :store_full_sti_class => true
         end
 
         it "groups by the inheritance column" do
-          relation.should_receive(:group) do |string|
-            string.should match(/"users"."type"/)
+          expect(relation).to receive(:group) do |string|
+            expect(string).to match(/"users"."type"/)
             relation
           end
 
@@ -483,12 +485,12 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
         context 'with a custom inheritance column' do
           before :each do
             model.column_names << 'custom_type'
-            model.stub :inheritance_column => 'custom_type'
+            allow(model).to receive_messages :inheritance_column => 'custom_type'
           end
 
           it "groups by the right column" do
-            relation.should_receive(:group) do |string|
-              string.should match(/"users"."custom_type"/)
+            expect(relation).to receive(:group) do |string|
+              expect(string).to match(/"users"."custom_type"/)
               relation
             end
 
@@ -501,14 +503,14 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
         let(:processor) { double('processor') }
 
         before :each do
-          source.stub! :delta_processor => processor
-          source.stub! :delta? => true
+          allow(source).to receive_messages :delta_processor => processor
+          allow(source).to receive_messages :delta? => true
         end
 
         it "filters by the provided clause" do
-          processor.should_receive(:clause).with(true).and_return('"delta" = 1')
-          relation.should_receive(:where) do |string|
-            string.should match(/"delta" = 1/)
+          expect(processor).to receive(:clause).with(true).and_return('"delta" = 1')
+          expect(relation).to receive(:where) do |string|
+            expect(string).to match(/"delta" = 1/)
             relation
           end
 
@@ -522,52 +524,52 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
     let(:processor) { double('processor', :reset_query => 'RESET DELTAS') }
 
     before :each do
-      source.stub :options => {}, :delta_processor => nil, :delta? => false
-      adapter.stub :utf8_query_pre => ['SET UTF8']
+      allow(source).to receive_messages :options => {}, :delta_processor => nil, :delta? => false
+      allow(adapter).to receive_messages :utf8_query_pre => ['SET UTF8']
     end
 
     it "adds a reset delta query if there is a delta processor and this is the core source" do
-      source.stub :delta_processor => processor
+      allow(source).to receive_messages :delta_processor => processor
 
-      builder.sql_query_pre.should include('RESET DELTAS')
+      expect(builder.sql_query_pre).to include('RESET DELTAS')
     end
 
     it "does not add a reset query if there is no delta processor" do
-      builder.sql_query_pre.should_not include('RESET DELTAS')
+      expect(builder.sql_query_pre).not_to include('RESET DELTAS')
     end
 
     it "does not add a reset query if this is a delta source" do
-      source.stub :delta_processor => processor
-      source.stub :delta? => true
+      allow(source).to receive_messages :delta_processor => processor
+      allow(source).to receive_messages :delta? => true
 
-      builder.sql_query_pre.should_not include('RESET DELTAS')
+      expect(builder.sql_query_pre).not_to include('RESET DELTAS')
     end
 
     it "sets the group_concat_max_len value if set" do
       source.options[:group_concat_max_len] = 123
 
-      builder.sql_query_pre.
-        should include('SET SESSION group_concat_max_len = 123')
+      expect(builder.sql_query_pre).
+        to include('SET SESSION group_concat_max_len = 123')
     end
 
     it "does not set the group_concat_max_len if not provided" do
       source.options[:group_concat_max_len] = nil
 
-      builder.sql_query_pre.select { |sql|
+      expect(builder.sql_query_pre.select { |sql|
         sql[/SET SESSION group_concat_max_len/]
-      }.should be_empty
+      }).to be_empty
     end
 
     it "sets the connection to use UTF-8 if required" do
       source.options[:utf8?] = true
 
-      builder.sql_query_pre.should include('SET UTF8')
+      expect(builder.sql_query_pre).to include('SET UTF8')
     end
 
     it "does not set the connection to use UTF-8 if not required" do
       source.options[:utf8?] = false
 
-      builder.sql_query_pre.should_not include('SET UTF8')
+      expect(builder.sql_query_pre).not_to include('SET UTF8')
     end
 
     it "adds a time-zone query by default" do
@@ -583,26 +585,26 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
 
   describe 'sql_query_range' do
     before :each do
-      adapter.stub!(:convert_nulls) { |string, default|
+      allow(adapter).to receive(:convert_nulls) { |string, default|
         "ISNULL(#{string}, #{default})"
       }
     end
 
     it "returns the relation's query" do
-      relation.stub! :to_sql => 'SELECT * FROM people'
+      allow(relation).to receive_messages :to_sql => 'SELECT * FROM people'
 
-      builder.sql_query_range.should == 'SELECT * FROM people'
+      expect(builder.sql_query_range).to eq('SELECT * FROM people')
     end
 
     it "returns nil if ranges are disabled" do
-      source.stub! :disable_range? => true
+      allow(source).to receive_messages :disable_range? => true
 
-      builder.sql_query_range.should be_nil
+      expect(builder.sql_query_range).to be_nil
     end
 
     it "selects the minimum primary key value, allowing for nulls" do
-      relation.should_receive(:select) do |string|
-        string.should match(/ISNULL\(MIN\(`users`.`id`\), 1\)/)
+      expect(relation).to receive(:select) do |string|
+        expect(string).to match(/ISNULL\(MIN\(`users`.`id`\), 1\)/)
         relation
       end
 
@@ -610,8 +612,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
     end
 
     it "selects the maximum primary key value, allowing for nulls" do
-      relation.should_receive(:select) do |string|
-        string.should match(/ISNULL\(MAX\(`users`.`id`\), 1\)/)
+      expect(relation).to receive(:select) do |string|
+        expect(string).to match(/ISNULL\(MAX\(`users`.`id`\), 1\)/)
         relation
       end
 
@@ -619,8 +621,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
     end
 
     it "shouldn't limit results to a range" do
-      relation.should_receive(:where) do |string|
-        string.should_not match(/`users`.`id` BETWEEN \$start AND \$end/)
+      expect(relation).to receive(:where) do |string|
+        expect(string).not_to match(/`users`.`id` BETWEEN \$start AND \$end/)
         relation
       end
 
@@ -630,8 +632,8 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
     it "does not add source conditions" do
       source.conditions << 'created_at > NOW()'
 
-      relation.should_receive(:where) do |string|
-        string.should_not match(/created_at > NOW()/)
+      expect(relation).to receive(:where) do |string|
+        expect(string).not_to match(/created_at > NOW()/)
         relation
       end
 
@@ -642,14 +644,14 @@ describe ThinkingSphinx::ActiveRecord::SQLBuilder do
       let(:processor) { double('processor') }
 
       before :each do
-        source.stub! :delta_processor => processor
-        source.stub! :delta? => true
+        allow(source).to receive_messages :delta_processor => processor
+        allow(source).to receive_messages :delta? => true
       end
 
       it "filters by the provided clause" do
-        processor.should_receive(:clause).with(true).and_return('`delta` = 1')
-        relation.should_receive(:where) do |string|
-          string.should match(/`delta` = 1/)
+        expect(processor).to receive(:clause).with(true).and_return('`delta` = 1')
+        expect(relation).to receive(:where) do |string|
+          expect(string).to match(/`delta` = 1/)
           relation
         end
 
