@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module ThinkingSphinx
   module Panes; end
 end
@@ -15,13 +17,13 @@ describe ThinkingSphinx::Panes::DistancePane do
     it "returns the object's geodistance attribute by default" do
       raw['geodist'] = 123.45
 
-      pane.distance.should == 123.45
+      expect(pane.distance).to eq(123.45)
     end
 
     it "converts string geodistances to floats" do
       raw['geodist'] = '123.450'
 
-      pane.distance.should == 123.45
+      expect(pane.distance).to eq(123.45)
     end
   end
 
@@ -29,13 +31,13 @@ describe ThinkingSphinx::Panes::DistancePane do
     it "returns the object's geodistance attribute by default" do
       raw['geodist'] = 123.45
 
-      pane.geodist.should == 123.45
+      expect(pane.geodist).to eq(123.45)
     end
 
     it "converts string geodistances to floats" do
       raw['geodist'] = '123.450'
 
-      pane.geodist.should == 123.45
+      expect(pane.geodist).to eq(123.45)
     end
   end
 end
