@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module ThinkingSphinx
   module Panes; end
 end
@@ -12,9 +14,9 @@ describe ThinkingSphinx::Panes::WeightPane do
 
   describe '#weight' do
     it "returns the object's weight by default" do
-      raw[ThinkingSphinx::SphinxQL.weight[:column]] = 101
+      raw["weight()"] = 101
 
-      pane.weight.should == 101
+      expect(pane.weight).to eq(101)
     end
   end
 end
