@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'spec_helper'
 
 describe ThinkingSphinx::Scopes do
@@ -17,29 +19,29 @@ describe ThinkingSphinx::Scopes do
     end
 
     it "creates new search" do
-      model.foo.class.should == ThinkingSphinx::Search
+      expect(model.foo.class).to eq(ThinkingSphinx::Search)
     end
 
     it "passes block result to constructor" do
-      model.foo.options[:with].should == {:foo => :bar}
+      expect(model.foo.options[:with]).to eq({:foo => :bar})
     end
 
     it "passes non-scopes through to the standard method error call" do
-      lambda { model.bar }.should raise_error(NoMethodError)
+      expect { model.bar }.to raise_error(NoMethodError)
     end
   end
 
   describe '#sphinx_scope' do
     it "saves the given block with a name" do
       model.sphinx_scope(:foo) { 27 }
-      model.sphinx_scopes[:foo].call.should == 27
+      expect(model.sphinx_scopes[:foo].call).to eq(27)
     end
   end
 
   describe '#default_sphinx_scope' do
     it "gets and sets the default scope depending on the argument" do
       model.default_sphinx_scope :foo
-      model.default_sphinx_scope.should == :foo
+      expect(model.default_sphinx_scope).to eq(:foo)
     end
   end
 end
